
/**
 *	XDataGrid Component
 *
 *	Copyright (C) 2004  Kamran Zafar
 *
 *	This program is free software; you can redistribute it and/or
 *	modify it under the terms of the GNU General Public License
 *	as published by the Free Software Foundation; either version 2
 *	of the License, or (at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package xeus.db.datagrid.xml.io;


import java.io.*;
import java.util.*;

import xeus.db.datagrid.*;

public class XDataGridXMLWriter {
    
    private String file;
    
    /** Creates a new instance of XDataGridXMLWriter */
    public XDataGridXMLWriter(String file) {
        this.file=file;
    }
    
    public void write(XDataSet dataSet) throws IOException
    {
        Vector models=dataSet.getModels();
        
        FileWriter out=new FileWriter(file);
        
        out.write("<?xml version=\"1.0\"?>");
        out.write("\r\n\t"+"<xdataset id=\""+dataSet.getID()+"\">");
        
        for(int i=0;i<models.size();i++) {
            out.write("\r\n\t\t"+"<xtable>");
            
            XDataGridTableModel model = (XDataGridTableModel) models.elementAt(i);
            
            out.write("\r\n\t\t\t"+"<xtableheader>");
            
            for(int j=0;j<model.getColumnCount();j++) {
                out.write("\r\n\t\t\t\t"+"<xtd>");
                out.write("\r\n\t\t\t\t\t"+model.getColumnName(j));
                out.write("\r\n\t\t\t\t"+"</xtd>");
            }
            
            out.write("\r\n\t\t\t"+"</xtableheader>");
            
            out.write("\r\n\t\t\t"+"<xtablebody>");
            Vector rows=model.getRows();
            
            for(int j=0;j<rows.size();j++) {
                out.write("\r\n\t\t\t\t"+"<xtr>");
                
                Vector row=(Vector)rows.elementAt(j);
                
                for(int k=0;k<row.size();k++) {
                    out.write("\r\n\t\t\t\t\t<xtd>");
                    
                    out.write("\r\n\t\t\t\t\t\t"+row.elementAt(k));
                    
                    out.write("\r\n\t\t\t\t\t</xtd>");
                }
                
                out.write("\r\n\t\t\t\t"+"</xtr>");
            }
            
            out.write("\r\n\t\t\t"+"</xtablebody>");
            
            out.write("\r\n\t\t"+"</xtable>");
        }
        
        out.write("\r\n\t"+"</xdataset>");
        
        out.flush();
        out.close();
    }
}